@@ -17,7 +17,7 @@ describe('Common', () => {
         assert.strictEqual(version, JSON.parse(fs.readFileSync('./package.json')).version);
     });
 
-    it('JSON.strigify()', () => {
+    it('JSON.stringify()', () => {
         const ast = parse(fixture, {
             filename: path.basename(fixtureFilename),
             positions: true
@@ -68,4 +68,25 @@ describe('Common', () => {
             });
         });
     });
+
+    it('generic option should work in fork()', () => {
+        const forkWithoutGeneric = fork({
+            // By default, generic is true, but we disable it
+            generic: false
+        });
+
+        const forkWithGeneric = fork({
+            // By default, generic is true
+        });
+
+        // Generic should be set
+        assert.strictEqual(forkWithoutGeneric.lexer.generic, false);
+        assert.strictEqual(forkWithGeneric.lexer.generic, true);
+
+        // Lexer match should depend on generic (<length> is generic type)
+        const node = parse('1px', { context: 'value' });
+
+        assert.throws(() => forkWithoutGeneric.lexer.match('<length>', node));
+        assert.doesNotThrow(() => forkWithGeneric.lexer.match('<length>', node));
+    });
 });
