@@ -69,7 +69,11 @@ describe('definitionSyntax.generate()', () => {
 
                     it(test.name, () => {
                         const actual = generate(parse(test.syntax)).replace(/\s+,/g, ',');
-                        const expected = test.syntax.replace(/\s+,/g, ',');
+                        const expected = test.syntax
+                            .replace(/\s+,/g, ',')
+                            .replace(/\{\s+(?=\d)/g, '{')
+                            .replace(/(?<=\d)\s+}/g, '}')
+                            .replace(/,\s+(\d+)}/g, ',$1}');
 
                         assert.strictEqual(actual, expected);
                     });
