@@ -98,7 +98,11 @@ describe('exports / entry points', () => {
         // collect all the selectors
         csstree.walk(expectedAst, function(node) {
             if (node.type === 'SelectorList' || node.type === 'Selector') {
-                selectors.push({ css: csstree.generate(node), expected: node });
+                selectors.push({
+                    css: csstree.generate(node),
+                    context: node.type === 'SelectorList' ? 'selectorList' : 'selector',
+                    expected: node
+                });
 
                 return csstree.walk.skip;
             }
@@ -106,7 +110,7 @@ describe('exports / entry points', () => {
 
         for (const test of selectors) {
             it(test.css, () => {
-                const ast = parseSelector(test.css);
+                const ast = parseSelector(test.css, { context: test.context });
                 assert.strictEqual(stringifyWithNoInfo(ast), stringifyWithNoInfo(test.expected));
             });
         }
