@@ -10,7 +10,9 @@ const wrapper = {
     }),
     mediaQuery: ast => ({
         type: 'MediaQuery',
-        children: [ast]
+        modifier: null,
+        mediaType: null,
+        condition: ast
     }),
     rule: ast => ({
         type: 'Rule',
@@ -103,6 +105,10 @@ function readTestDir(dir, result, scope) {
                 return readTestDir(filename, result, scope);
             }
 
+            if (path.extname(filename) !== '.json') {
+                return;
+            }
+
             const locator = new JsonLocator(filename);
             const origTests = JSON.parse(fs.readFileSync(filename));
             const tests = {};
