@@ -5,11 +5,9 @@ import { JsonLocator } from '../helpers/JsonLocator.js';
 const __dirname = 'fixtures/definition-syntax-match';
 
 export function forEachTest(factory) {
-    for (const filename in tests) {
-        const file = tests[filename];
-
-        for (const key in file) {
-            factory(key, file[key]);
+    for (const file of Object.values(tests)) {
+        for (const [key, test] of Object.entries(file)) {
+            factory(key, test);
         }
     };
 }
