@@ -6,11 +6,8 @@ import { JsonLocator } from '../helpers/JsonLocator.js';
 const __dirname = 'fixtures/definition-syntax';
 
 export function forEachTest(factory) {
-    for (const filename in tests) {
-        const file = tests[filename];
-
-        for (const key in file) {
-            const test = file[key];
+    for (const file of Object.values(tests)) {
+        for (const test of Object.values(file)) {
             const syntax = test.syntax;
             const lexer = test.lexer ? createLexer(test.lexer) : defaultLexer;
 
@@ -36,9 +33,7 @@ export function forEachTest(factory) {
 }
 
 export function forEachAtrulePreludeTest(factory) {
-    for (const atruleName in atruleTests) {
-        const testset = atruleTests[atruleName];
-
+    for (const [atruleName, testset] of Object.entries(atruleTests)) {
         if (testset.prelude) {
             const test = testset.prelude;
             for (const field in test) {
@@ -62,13 +57,10 @@ export function forEachAtrulePreludeTest(factory) {
 }
 
 export function forEachAtruleDescriptorTest(factory) {
-    for (const atruleName in atruleTests) {
-        const testset = atruleTests[atruleName];
-
+    for (const [atruleName, testset] of Object.entries(atruleTests)) {
         if (testset.descriptors) {
-            for (const descriptorName in testset.descriptors) {
-                const test = testset.descriptors[descriptorName];
-                for (const field in test) {
+            for (const [descriptorName, test] of Object.entries(testset.descriptors)) {
+                for (const field of Object.keys(test)) {
                     if (field !== 'valid' && field !== 'invalid') {
                         continue;
                     }
