@@ -20,9 +20,7 @@ function processTests(tests, key, type, locator) {
 }
 
 export function forEachTest(testType, factory) {
-    for (const filename in tests) {
-        const file = tests[filename];
-
+    for (const file of Object.values(tests)) {
         Object.keys(file[testType]).forEach(key => factory(
             file[testType][key].name,
             file[testType][key].value,
