@@ -1,3 +1,11 @@
+export const cssWideKeywords = [
+    'unset',
+    'initial',
+    'inherit',
+    'revert',
+    'revert-layer'
+];
+
 export function lazyValues(dict) {
     const result = Object.create(null);
 
