@@ -3,16 +3,17 @@ import { parse, lexer, fork } from 'css-tree';
 import { lazyValues, cssWideKeywords } from './helpers/index.js';
 import { forEachTest } from './fixture/definition-syntax.js';
 
-const values = lazyValues({
+const lazy = lazyValues({
     bar: () => parse('bar', { context: 'value' }),
     qux: () => parse('qux', { context: 'value' }),
-    customSyntax: () => fork(function(prev, assign) {
-        return assign(prev, {
-            properties: {
-                foo: 'bar',
-                '-baz-foo': 'qux'
-            }
-        });
+    customSyntax: () => fork({
+        properties: {
+            foo: 'bar',
+            '-baz-foo': 'qux'
+        }
+    }),
+    customCssWideKeywords: () => fork({
+        cssWideKeywords: ['test']
     })
 });
 
@@ -25,21 +26,21 @@ function getMatch(lexer, property, value, syntax) {
 describe('Lexer#matchProperty()', () => {
     describe('vendor prefixes and hacks', () => {
         it('vendor prefix', () => {
-            const match = values.customSyntax.lexer.matchProperty('-vendor-foo', values.bar);
+            const match = lazy.customSyntax.lexer.matchProperty('-vendor-foo', lazy.bar);
 
             assert(match.matched);
             assert.strictEqual(match.error, null);
         });
 
         it('hacks', () => {
-            const match = values.customSyntax.lexer.matchProperty('_foo', values.bar);
+            const match = lazy.customSyntax.lexer.matchProperty('_foo', lazy.bar);
 
             assert(match.matched);
             assert.strictEqual(match.error, null);
         });
 
         it('vendor prefix and hack', () => {
-            const match = values.customSyntax.lexer.matchProperty('_-vendor-foo', values.bar);
+            const match = lazy.customSyntax.lexer.matchProperty('_-vendor-foo', lazy.bar);
 
             assert(match.matched);
             assert.strictEqual(match.error, null);
@@ -48,19 +49,19 @@ describe('Lexer#matchProperty()', () => {
         it('case insensetive with vendor prefix and hack', () => {
             let match;
 
-            match = values.customSyntax.lexer.matchProperty('FOO', values.bar);
+            match = lazy.customSyntax.lexer.matchProperty('FOO', lazy.bar);
             assert(match.matched);
             assert.strictEqual(match.error, null);
 
-            match = values.customSyntax.lexer.matchProperty('-VENDOR-Foo', values.bar);
+            match = lazy.customSyntax.lexer.matchProperty('-VENDOR-Foo', lazy.bar);
             assert(match.matched);
             assert.strictEqual(match.error, null);
 
-            match = values.customSyntax.lexer.matchProperty('_FOO', values.bar);
+            match = lazy.customSyntax.lexer.matchProperty('_FOO', lazy.bar);
             assert(match.matched);
             assert.strictEqual(match.error, null);
 
-            match = values.customSyntax.lexer.matchProperty('_-VENDOR-Foo', values.bar);
+            match = lazy.customSyntax.lexer.matchProperty('_-VENDOR-Foo', lazy.bar);
             assert(match.matched);
             assert.strictEqual(match.error, null);
         });
@@ -68,18 +69,18 @@ describe('Lexer#matchProperty()', () => {
         it('should use verdor version first', () => {
             let match;
 
-            match = values.customSyntax.lexer.matchProperty('-baz-foo', values.qux);
+            match = lazy.customSyntax.lexer.matchProperty('-baz-foo', lazy.qux);
             assert(match.matched);
             assert.strictEqual(match.error, null);
 
-            match = values.customSyntax.lexer.matchProperty('-baz-baz-foo', values.qux);
+            match = lazy.customSyntax.lexer.matchProperty('-baz-baz-foo', lazy.qux);
             assert.strictEqual(match.matched, null);
             assert.strictEqual(match.error.message, 'Unknown property `-baz-baz-foo`');
         });
     });
 
     it('custom property', () => {
-        const match = lexer.matchProperty('--foo', values.bar);
+        const match = lexer.matchProperty('--foo', lazy.bar);
 
         assert.strictEqual(match.matched, null);
         assert.strictEqual(match.error.message, 'Lexer matching doesn\'t applicable for custom properties');
@@ -87,12 +88,19 @@ describe('Lexer#matchProperty()', () => {
 
     describe('should match css wide keywords', function() {
         for (const keyword of cssWideKeywords) {
-            it(keyword, () => {
-                const match = lexer.matchProperty('color', parse(keyword, { context: 'value' }));
+            const match = lexer.matchProperty('color', keyword);
 
-                assert(match.matched);
-                assert.strictEqual(match.error, null);
-            });
+            assert(match.matched);
+            assert.strictEqual(match.error, null);
+        }
+    });
+
+    it('should match css wide keywords', function() {
+        for (const keyword of cssWideKeywords.concat('test')) {
+            const match = lazy.customCssWideKeywords.lexer.matchProperty('color', keyword);
+
+            assert(match.matched, keyword);
+            assert.strictEqual(match.error, null, keyword);
         }
     });
 
