@@ -41,6 +41,10 @@ describe('lexer', () => {
         });
 
         assert.deepStrictEqual(customLexer.validate(), {
+            errors: [
+                '<invalid> used missed syntax definition <foo>',
+                '<\'invalid\'> used broken syntax definition <invalid>'
+            ],
             types: [
                 'invalid'
             ],
@@ -77,6 +81,20 @@ describe('lexer', () => {
         assert.deepStrictEqual(Object.keys(customLexer.units), Object.keys(lexer.units));
     });
 
+    it('should allow to override CSS wide keywords', () => {
+        const customLexer = createLexer({
+            cssWideKeywords: ['foo', 'bar'],
+            generic: true,
+            properties: {
+                test: '<number>'
+            }
+        });
+
+        assert.notStrictEqual(customLexer.matchProperty('test', 'foo').matched, null);
+        assert.notStrictEqual(customLexer.matchProperty('test', 'bar').matched, null);
+        assert.strictEqual(customLexer.matchProperty('test', 'inherit').matched, null);
+    });
+
     describe('should allow append definitions', function() {
         const customSyntax = fork({
             properties: {
@@ -110,6 +128,7 @@ describe('lexer', () => {
     describe('dump & recovery', () => {
         const customLexer = createLexer({
             generic: true,
+            cssWideKeywords: ['wide'],
             units: {
                 length: ['aa', 'bb']
             },
@@ -124,6 +143,7 @@ describe('lexer', () => {
         it('custom syntax should not affect base syntax', () => {
             assert.strictEqual(lexer.validate(), null);
             assert.strictEqual(lexer.matchProperty('test', '1 2aa 3').matched, null);
+            assert.strictEqual(lexer.matchProperty('test', 'wide').matched, null);
             assert.notStrictEqual(lexer.matchProperty('color', 'red').matched, null);
         });
 
@@ -133,6 +153,7 @@ describe('lexer', () => {
 
         it('custom syntax should match own grammar only', () => {
             assert.notStrictEqual(customLexer.matchProperty('test', '1 2aa 3').matched, null);
+            assert.notStrictEqual(customLexer.matchProperty('test', 'wide').matched, null);
             assert.strictEqual(customLexer.matchProperty('color', 'red').matched, null);
         });
 
@@ -144,6 +165,7 @@ describe('lexer', () => {
 
             assert.strictEqual(recoverySyntax.lexer.validate(), null);
             assert.notStrictEqual(recoverySyntax.lexer.matchProperty('test', '1 2aa 3').matched, null);
+            assert.notStrictEqual(recoverySyntax.lexer.matchProperty('test', 'wide').matched, null);
         });
     });
 });
