@@ -102,10 +102,11 @@ describe('AST traversal', () => {
             'AtrulePrelude',
             'Block',
             'ClassSelector',
+            'Condition',
             'Declaration',
             'Dimension',
+            'Feature',
             'Function',
-            'MediaFeature',
             'MediaQuery',
             'MediaQueryList',
             'Nth',
@@ -168,8 +169,10 @@ describe('AST traversal', () => {
 
             walk(values.ast, {
                 enter(node) {
-                    if (node.name || node.property) {
-                        visitedNames.push(node.name || node.property);
+                    const ref = node.name || node.property || node.mediaType;
+
+                    if (ref) {
+                        visitedNames.push(ref);
                     }
                 }
             });
@@ -187,8 +190,10 @@ describe('AST traversal', () => {
             walk(values.ast, {
                 reverse: true,
                 enter(node) {
-                    if (node.name || node.property) {
-                        visitedNames.push(node.name || node.property);
+                    const ref = node.name || node.property || node.mediaType;
+
+                    if (ref) {
+                        visitedNames.push(ref);
                     }
                 }
             });
@@ -561,7 +566,7 @@ describe('AST traversal', () => {
         it('should throws when visit has wrong value', () => {
             assert.throws(
                 () => walk(ast, { visit: 'Foo' }),
-                /Bad value `Foo` for `visit` option \(should be: AnPlusB, Atrule, AtrulePrelude, AttributeSelector, Block, Brackets, CDC, CDO, ClassSelector, Combinator, Comment, Declaration, DeclarationList, Dimension, Function, Hash, IdSelector, Identifier, MediaFeature, MediaQuery, MediaQueryList, NestingSelector, Nth, Number, Operator, Parentheses, Percentage, PseudoClassSelector, PseudoElementSelector, Ratio, Raw, Rule, Selector, SelectorList, String, StyleSheet, TypeSelector, UnicodeRange, Url, Value, WhiteSpace\)/
+                /Bad value `Foo` for `visit` option/
             );
         });
     });
