@@ -12,7 +12,7 @@ function isPlusMinusOperator(node) {
 
 export default {
     getNode,
-    onWhiteSpace: function(next, children) {
+    onWhiteSpace(next, children) {
         if (isPlusMinusOperator(next)) {
             next.value = ' ' + next.value;
         }
